//
//  ContentMainBannerViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/12/11.
//

import Foundation
import Combine

final class ContentMainBannerViewModel: ObservableObject {
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var currentIndex = 0
    @Published var timer = Timer.publish(every: 3, on: .main, in: .common).autoconnect()
    
    @Published var bannerList = [GetAudioContentBannerResponse]()
    
    func getBannerList() {
        isLoading = true
        
        repository.getMainBannerList()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[GetAudioContentBannerResponse]>.self, from: responseData)
                    self.isLoading = false
                    
                    if let data = decoded.data, decoded.success {
                        self.bannerList.removeAll()
                        self.bannerList.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "배너를 불러오지 못했습니다. 다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "배너를 불러오지 못했습니다. 다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                    self.isLoading = false
                }
            }
            .store(in: &subscription)
    }
}
