//
//  SeriesContentAllViewModel.swift
//  SodaLive
//
//  Created by klaus on 4/30/24.
//

import Foundation
import Combine

final class SeriesContentAllViewModel: ObservableObject {
    private let repository = SeriesRepository()
    private var subscription = Set<AnyCancellable>()
    
    var seriesId = 0
    
    @Published var isLoading = false
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var seriesContentList = [GetSeriesContentListItem]()
    
    @Published var sortType: SeriesListAllViewModel.SeriesSortType = .NEWEST {
        didSet {
            page = 1
            isLast = false
            getSeriesContentList()
        }
    }
    
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getSeriesContentList() {
        if !isLoading && !isLast {
            isLoading = true
            
            repository
                .getSeriesContentList(seriesId: seriesId, page: page, size: pageSize, sortType: sortType)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetSeriesContentListResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                self.seriesContentList.removeAll()
                            }
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.seriesContentList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                    
                    self.isLoading = false
                }
                .store(in: &subscription)
        }
    }
}
