//
//  SectionEventBannerView.swift
//  SodaLive
//
//  Created by klaus on 2023/08/09.
//

import SwiftUI
import Kingfisher

struct SectionEventBannerView: View {
    
    @State private var currentIndex = 0
    @State private var timer = Timer.publish(every: 3, on: .main, in: .common).autoconnect()
    
    let items: [EventItem]
    
    var body: some View {
        VStack(spacing: 13.3) {
            TabView(selection: $currentIndex) {
                ForEach(0..<items.count, id: \.self) { index in
                    let item = items[index]
                    if let url = item.thumbnailImageUrl.addingPercentEncoding(withAllowedCharacters: .urlQueryAllowed) {
                        KFImage(URL(string: url))
                            .cancelOnDisappear(true)
                            .downsampling(
                                size: CGSize(
                                    width: screenSize().width,
                                    height: screenSize().width * 300 / 1000
                                )
                            )
                            .resizable()
                            .scaledToFill()
                            .frame(
                                width: screenSize().width,
                                height: screenSize().width * 300 / 1000,
                                alignment: .center
                            )
                            .tag(index)
                            .onTapGesture {
                                if let _ = item.detailImageUrl {
                                    AppState.shared.setAppStep(step: .eventDetail(event: item))
                                } else if let link = item.link, link.trimmingCharacters(in: .whitespaces).count > 0, let url = URL(string: link), UIApplication.shared.canOpenURL(url) {
                                    UIApplication.shared.open(url)
                                }
                            }
                    } else {
                        KFImage(URL(string: item.thumbnailImageUrl))
                            .cancelOnDisappear(true)
                            .downsampling(
                                size: CGSize(
                                    width: screenSize().width,
                                    height: screenSize().width * 300 / 1000
                                )
                            )
                            .resizable()
                            .scaledToFill()
                            .frame(
                                width: screenSize().width,
                                height: screenSize().width * 300 / 1000,
                                alignment: .center
                            )
                            .tag(index)
                            .onTapGesture {
                                if let _ = item.detailImageUrl {
                                    AppState.shared.setAppStep(step: .eventDetail(event: item))
                                } else if let link = item.link, link.trimmingCharacters(in: .whitespaces).count > 0, let url = URL(string: link), UIApplication.shared.canOpenURL(url) {
                                    UIApplication.shared.open(url)
                                }
                            }
                    }
                }
            }
            .tabViewStyle(PageTabViewStyle(indexDisplayMode: .never))
            .frame(
                width: screenSize().width,
                height: screenSize().width * 300 / 1000,
                alignment: .center
            )
            
            HStack(spacing: 4) {
                ForEach(0..<items.count, id: \.self) { index in
                    Capsule()
                        .foregroundColor(index == currentIndex ? .button : .gray90)
                        .frame(
                            width: index == currentIndex ? 18 : 6,
                            height: 6
                        )
                        .tag(index)
                }
            }
        }
        .onAppear {
            timer = Timer.publish(every: 3, on: .main, in: .common).autoconnect()
        }
        .onDisappear {
            timer.upstream.connect().cancel()
        }
        .onReceive(timer) { _ in
            DispatchQueue.main.async {
                withAnimation {
                    if currentIndex == items.count - 1 {
                        currentIndex = 0
                    } else {
                        currentIndex += 1
                    }
                }
            }
        }
    }
}

struct SectionEventBannerView_Previews: PreviewProvider {
    static var previews: some View {
        SectionEventBannerView(items: [])
    }
}
