//
//  EventListViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/10.
//

import Foundation
import Combine

final class EventListViewModel: ObservableObject {
    private let eventRepository = EventRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published private(set) var events = [EventItem]()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    private var page = 1
    private let size = 10
    
    func getEvents() {
        isLoading = true
        eventRepository.getEvents()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<GetEventResponse>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        self.events.append(contentsOf: data.eventList)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
